describe("Alchemy API Params", function() {

	describe("initialization",function(){
		
		describe("output mode", function() {
			it("can initialize", function() {
				var params = new Alchemy.params({
					outputMode : "json"
				});
				expect(params.outputMode()).toEqual("json");
				params = new Alchemy.params({
					outputMode : "xml"
				});
				expect(params.outputMode()).toEqual("xml");
				params = new Alchemy.params({
					outputMode : "rdf"
				});
				expect(params.outputMode()).toEqual("rdf");
			});
			
			it("sets json by default", function() {
				var params = new Alchemy.params();
				expect(params.outputMode()).toEqual("json");
			});
		});
		
		describe("url",function(){
			it("can initialize", function() {
				var params = new Alchemy.params({
					url : "www.google.com"
				});
				expect(params.url()).toEqual("www.google.com");
			});
			
			it("sets blank by default", function() {
				var params = new Alchemy.params();
				expect(params.url()).toEqual("");
			});
		});
		
		describe("html",function(){
			it("can initialize", function() {
				var params = new Alchemy.params({
					html : "www.google.com"
				});
				expect(params.html()).toEqual("www.google.com");
			});
			
			it("sets blank by default", function() {
				var params = new Alchemy.params();
				expect(params.html()).toEqual("");
			});
		});
		
		describe("text",function(){
			it("can initialize response type", function() {
				var params = new Alchemy.params({
					text : "this is text"
				});
				expect(params.text()).toEqual("this is text");
			});
			
			it("sets blank by default", function() {
				var params = new Alchemy.params();
				expect(params.text()).toEqual("");
			});
		});
		
	});
	
	describe("parameter string",function(){
		
		it("builds param with no params specified",function(){
			var params = new Alchemy.params();
			var expected = "&outputMode=json";
			expect(params.getParameterString()).toEqual(expected);
		});
		it("builds param from url",function(){
			var params = new Alchemy.params({url:"www.google.com"});
			var expected = "&url=www.google.com&outputMode=json";
			expect(params.getParameterString()).toEqual(expected);
		});
		it("builds param from html",function(){
			var params = new Alchemy.params({html:"www.google.com"});
			var expected = "&html=www.google.com&outputMode=json";
			expect(params.getParameterString()).toEqual(expected);
		});
		it("builds param from text",function(){
			var params = new Alchemy.params({text:"this is text"});
			var expected = "&text=this%20is%20text&outputMode=json";
			expect(params.getParameterString()).toEqual(expected);
		});
	});
});
